Learn R Programming

poisonfrogs (version 1.0.2)

poison_palettes_names: List the names of available color palettes inspired in poison frogs and other frog species.

Description

List the names of available color palettes inspired in poison frogs and other frog species.

Usage

poison_palettes_names()

Arguments

Value

A character vector of palette names.

Examples

Run this code

poison_palettes_names()

Run the code above in your browser using DataLab